## SCENARIO 6: Zero DP, mocked

### INPUTS

#### GROUP 1: Event Sequence

# | Set Name | Timer Name | Event | Elapsed Time | CPU Time
--- | --- | --- | --- | --- | ---
1 | Set 1 |  | CON | 3.000 | .800
2 | Set 1 | Timer 1 | INC | 33.123 | 9.256
3 | Set 1 |  | GETF | 63.246 | 17.712

####

#### GROUP 2: Scalars

# | Mock Flag | Time Width | Decimal Places (Totals) | Decimal Places (per call) | Calls Width
--- | --- | --- | --- | --- | ---
1 | Y | 7 | 0 | 3 | 5

####

### OUTPUTS

#### GROUP 1: Set 1: Empty as expected: SUCCESS

#### GROUP 2: Set 1 (formatted)

# | Line
--- | ---
1 | Timer Elapsed CPU Calls Ela/Call CPU/Call
2 | ------- ------- ------- ----- ---------- ----------
3 | Timer 1 30 8 1 30.123 8.456
4 | (Other) 30 8 1 30.123 8.456
5 | ------- ------- ------- ----- ---------- ----------
6 | Total 60 17 2 30.123 8.456
7 | ------- ------- ------- ----- ---------- ----------

#### 0 failed of 7: SUCCESS

#### GROUP 3: Set 2: Empty as expected: SUCCESS

#### GROUP 4: Set 2 (formatted): Empty as expected: SUCCESS

#### GROUP 5: Self (unmocked): Empty as expected: SUCCESS

#### GROUP 6: Self (unmocked, formatted): Empty as expected: SUCCESS

#### GROUP 7: Results: Empty as expected: SUCCESS

#### GROUP 8: Exception: Empty as expected: SUCCESS

## 0 failed of 8: SUCCESS